==> stats-collector_2.1.0~rc2.orig.tar.gz: stats-collector-2.1.0~rc2/stats_collector/data_collector.py <==
import datetime
import os
import sys

from stats_collector.dbconn import DBConn
from stats_collector import FRED_DB, LOG_DB, config
from stats_collector.stats.stat_registry import stat_registry
from stats_collector.utils import time_measure


class DataCollector(object):
    def __init__(self):
        self.databases = {
            FRED_DB: DBConn(0),
            LOG_DB: DBConn(1),
        }
        self.run_date = None

    def _get_context(self):
        context = {}
        context['date'] = '%d-%02d-%02d' % (self.run_date.year, self.run_date.month, self.run_date.day)
        tommorow = self.run_date + datetime.timedelta(1)
        context['midnight'] = "'%d-%02d-%02d'::timestamp" % (tommorow.year, tommorow.month, tommorow.day) # midnight at the end of day of 'date'
        context['monitoring_domain'] = config.MONITORING_DOMAIN
        context['monitoring_cltrid'] = config.MONITORING_CLTRID
        context['log_req_cond_base'] = """
            r.time_begin BETWEEN '%(date)s'::timestamp AND %(midnight)s
            AND NOT r.is_monitoring
        """ % context
        context['log_req_cond_epp'] = """
            %(log_req_cond_base)s
            AND r.service_id = 3 -- epp
        """ % context
        context['log_req_cond_mojeid'] = """
            %(log_req_cond_base)s
            AND r.service_id = 6 -- mojeid
        """ % context
        return context

    def get_data(self, run_date, stat_classes):
        self.run_date = run_date

        context = self._get_context()

        outputs = {} # dict {stat name: csv output of the stat}
        for stat_class in stat_classes:
            stat = stat_class(self.databases, context)
            stat_data = time_measure(stat.get_data)
            if stat_data:
                outputs[stat.name] = outputs.get(stat.name, '') + stat_data

        return outputs

    @staticmethod
    def stat_filename(date_string, stat_name):
        return os.path.join(config.STAT_DIR, '%s-%s.csv' % (date_string, stat_name))

    def save_data(self, data, force_overwrite=False):
        ''' Writes data of statistics to their files.'''

        date_string = '%d%02d%02d' % (self.run_date.year, self.run_date.month, self.run_date.day)
        if not os.path.exists(config.STAT_DIR):
            os.makedirs(config.STAT_DIR)

        # get already created output files in STAT_DIR to skip saving...
        skip = set()
        for stat_name in data:
            fn = self.stat_filename(date_string, stat_name)
            if os.path.exists(fn):
                if force_overwrite:
                    os.remove(fn)
                else:
                    skip.add(fn)

        rc = 0
        for stat_name, rows in data.items():
            fn = self.stat_filename(date_string, stat_name)
            if fn in skip:
                sys.stderr.write('skipping file save \'%s\' - already exists\n' % fn)
                rc = 1
                continue
            else:
                stat_file = open(fn, 'a')
                stat_file.write(rows)
        return rc

    def get_and_save_data(self, run_date, stat_classes=None, force_overwrite=False):
        ''' Proxy method that just calls get_data and save_data.'''
        data = self.get_data(run_date, stat_classes)
        if data:
            return self.save_data(data, force_overwrite)
        elif config.DEBUG:
            print "No data to write"

==> stats-collector_2.4.0.orig.tar.gz: stats-collector-2.4.0/stats_collector/data_collector.py <==
import datetime
import os
import sys

from stats_collector import FRED_DB, LOG_DB, config
from stats_collector.dbconn import DBConn
from stats_collector.utils import time_measure


class DataCollector(object):
    def __init__(self):
        self.databases = {
            FRED_DB: DBConn(0),
            LOG_DB: DBConn(1),
        }
        self.run_date = None

    def _get_context(self):
        context = {}
        context['date'] = '%d-%02d-%02d' % (self.run_date.year, self.run_date.month, self.run_date.day)
        tommorow = self.run_date + datetime.timedelta(1)
        # midnight at the end of day of 'date'
        context['midnight'] = "'%d-%02d-%02d'::timestamp" % (tommorow.year, tommorow.month, tommorow.day)
        context['monitoring_domain'] = config.MONITORING_DOMAIN
        context['monitoring_cltrid'] = config.MONITORING_CLTRID
        context['log_req_cond_base'] = """
            r.time_begin BETWEEN '%(date)s'::timestamp AND %(midnight)s
            AND NOT r.is_monitoring
        """ % context
        context['log_req_cond_epp'] = """
            %(log_req_cond_base)s
            AND r.service_id = 3 -- epp
        """ % context
        context['log_req_cond_mojeid'] = """
            %(log_req_cond_base)s
            AND r.service_id = 6 -- mojeid
        """ % context
        return context

    def get_data(self, run_date, stat_classes):
        self.run_date = run_date

        context = self._get_context()

        outputs = {}  # dict {stat name: csv output of the stat}
        for stat_class in stat_classes:
            stat = stat_class(self.databases, context)
            stat_data = time_measure(stat.get_data)
            if stat_data:
                outputs[stat.name] = outputs.get(stat.name, '') + stat_data

        return outputs

    @staticmethod
    def stat_filename(date_string, stat_name):
        return os.path.join(config.STAT_DIR, '%s-%s.csv' % (date_string, stat_name))

    def save_data(self, data, force_overwrite=False):
        ''' Writes data of statistics to their files.'''

        date_string = '%d%02d%02d' % (self.run_date.year, self.run_date.month, self.run_date.day)
        if not os.path.exists(config.STAT_DIR):
            os.makedirs(config.STAT_DIR)

        # get already created output files in STAT_DIR to skip saving...
        skip = set()
        for stat_name in data:
            fn = self.stat_filename(date_string, stat_name)
            if os.path.exists(fn):
                if force_overwrite:
                    os.remove(fn)
                else:
                    skip.add(fn)

        rc = 0
        for stat_name, rows in data.items():
            fn = self.stat_filename(date_string, stat_name)
            if fn in skip:
                sys.stderr.write('skipping file save \'%s\' - already exists\n' % fn)
                rc = 1
                continue
            else:
                stat_file = open(fn, 'a')
                stat_file.write(rows)
        return rc

    def get_and_save_data(self, run_date, stat_classes=None, force_overwrite=False):
        ''' Proxy method that just calls get_data and save_data.'''
        data = self.get_data(run_date, stat_classes)
        if data:
            return self.save_data(data, force_overwrite)
        elif config.DEBUG:
            print "No data to write"
